@@ -44,10 +44,10 @@ namespace Kwave
 	PitchShiftFilter();
 
 	/** Destructor */
-	virtual ~PitchShiftFilter();
+        virtual ~PitchShiftFilter() Q_DECL_OVERRIDE;
 
 	/** does the calculation */
-	void goOn() Q_DECL_OVERRIDE;
+        virtual void goOn() Q_DECL_OVERRIDE;
 
     signals:
 
